serverpod_auth_email_flutter library

Classes

EmailAuthController
Controller for email authentication.
SignInWithEmailButton
Sign in with Email button. When pressed, a pop-up window appears with fields for entering login, email and password.
SignInWithEmailButtonState
State for Sign in with email button.
SignInWithEmailDialogLabels
A collection of String used in the SignInWithEmailDialog. When null the default/english labels will be used.

Enums

InitPage
Configure the initial page of the sign in dialog.