SignInWithEmailDialogLabels class

A collection of String used in the SignInWithEmailDialog. When null the default/english labels will be used.

Constructors

SignInWithEmailDialogLabels({required String inputHintUserName, required String inputHintEmail, required String inputHintPassword, required String buttonTitleSignUp, required String buttonTitleOpenSignUp, required String buttonTitleOpenSignIn, required String buttonTitleSignIn, required String buttonTitleForgotPassword, required String buttonTitleResetPassword, required String inputHintNewPassword, required String buttonTitleBack, required String messageEmailVerificationSent, required String inputHintValidationCode, required String messagePasswordResetSent, required String errorMessageUserNameRequired, required String errorMessageInvalidEmail, required String minimumLengthMessage(int length), required String maximumLengthMessage(int length), required String errorMessageEmailInUse, required String messageEnterCode, required String errorMessageIncorrectCode, required String errorMessageIncorrectPassword})
Constructor for the SignInWithEmailDialog labels. All parameters are required to ensure complete localization.
SignInWithEmailDialogLabels.enUS({String? inputHintUserName, String? inputHintEmail, String? inputHintPassword, String? buttonTitleSignUp, String? buttonTitleOpenSignUp, String? buttonTitleOpenSignIn, String? buttonTitleSignIn, String? buttonTitleForgotPassword, String? buttonTitleResetPassword, String? inputHintNewPassword, String? buttonTitleBack, String? messageEmailVerificationSent, String? inputHintValidationCode, String? messagePasswordResetSent, String? errorMessageUserNameRequired, String? errorMessageInvalidEmail, String minimumLengthMessage(int length)?, String maximumLengthMessage(int length)?, String? errorMessageEmailInUse, String? messageEnterCode, String? errorMessageIncorrectCode, String? errorMessageIncorrectPassword})
Factory constructor that creates a new instance with default English labels. Individual values can be overridden by providing them as parameters.
factory

Properties

buttonTitleBack String
Button text for navigating back. Used in various forms to return to the previous screen.
final
buttonTitleForgotPassword String
Button text for the forgot password option. Used in the sign-in form below the password field.
final
buttonTitleOpenSignIn String
Button text for navigating to sign-in form. Used in the sign-up form to return to sign-in.
final
buttonTitleOpenSignUp String
Button text for navigating to sign-up form. Used in the sign-in form to switch to account creation.
final
buttonTitleResetPassword String
Button text for initiating password reset. Used in the password reset form.
final
buttonTitleSignIn String
Button text for the sign-in submit button. Used in the sign-in form to authenticate the user.
final
buttonTitleSignUp String
Button text for the sign-up submit button. Used in the sign-up form to create a new account.
final
errorMessageEmailInUse String
Error message shown when email is already registered. Displayed under the email field in sign-up form.
final
errorMessageIncorrectCode String
Error message shown when verification code is incorrect. Displayed in both email verification and password reset forms.
final
errorMessageIncorrectPassword String
Error message shown when password is incorrect. Displayed under the password field in sign-in form.
final
errorMessageInvalidEmail String
Error message shown for invalid email format. Displayed under the email field in both sign-in and sign-up forms.
final
errorMessageUserNameRequired String
Error message shown when username is empty. Displayed under the username field in sign-up form.
final
hashCode int
The hash code for this object.
no setterinherited
inputHintEmail String
Hint text for the email input field. Used in both sign-in and sign-up forms TextField.
final
inputHintNewPassword String
Hint text for the new password input field. Used in the password reset form TextField.
final
inputHintPassword String
Hint text for the password input field. Used in both sign-in and sign-up forms TextField.
final
inputHintUserName String
Hint text for the username input field. Used in the sign-up form TextField.
final
inputHintValidationCode String
Hint text for the validation code input field. Used in both email verification and password reset forms TextField.
final
maximumLengthMessage String Function(int length)
Callback function that returns a formatted string for maximum length validation. Takes the maximum allowed length as a parameter. Used for password length validation messages.
final
messageEmailVerificationSent String
Message shown after sending email verification code. Displayed in the email verification screen.
final
messageEnterCode String
Message prompting to enter verification code. Used in both email verification and password reset screens.
final
messagePasswordResetSent String
Message shown after sending password reset code. Displayed in the password reset verification screen.
final
minimumLengthMessage String Function(int length)
Callback function that returns a formatted string for minimum length validation. Takes the required length as a parameter. Used for password length validation messages.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited